@@ -337,12 +337,8 @@ module TestReplTypeCompletor
       assert_call('a, ((b=1).c, d) = 1; b.', include: Integer)
       assert_call('a, b[c=1] = 1; c.', include: Integer)
       assert_call('a, b[*(c=1)] = 1; c.', include: Integer)
-      assert_call('a, b[**(c=1)] = 1; c.', include: Integer)
-      assert_call('a, b[&(c=1)] = 1; c.', include: Integer)
       assert_call('a, b[] = 1; a.', include: Integer)
       assert_call('def f(*); a, b[*] = 1; a.', include: Integer)
-      assert_call('def f(&); a, b[&] = 1; a.', include: Integer)
-      assert_call('def f(**); a, b[**] = 1; a.', include: Integer)
       # incomplete massign
       assert_analyze_type('a,b', :lvar_or_method, 'b')
       assert_call('(a=1).b, a.a', include: Integer)
@@ -518,9 +514,6 @@ module TestReplTypeCompletor
       assert_call('END{1.', include: Integer)
       # MatchWrite
       assert_call('a=1; /(?<a>)/=~b; a.', include: [String, NilClass], exclude: Integer)
-      # OperatorWrite with block `a[&b]+=c`
-      assert_call('a=[1]; (a[0,&:to_a]+=1.0).', include: Float)
-      assert_call('a=[1]; (a[0,&b]+=1.0).', include: Float)
     end
 
     def test_hash
@@ -560,6 +553,8 @@ module TestReplTypeCompletor
       assert_call('[1].tap{it.', include: Array)
       assert_call('loop{it.', include: NilClass, exclude: Object)
       assert_call('[:a].each_with_index{it.', include: Symbol, exclude: [Integer, Array])
+      assert_call(':outer.tap{p it; "inner".tap{p it; it.', include: String, exclude: Symbol)
+      assert_call(':outer.tap{p it; "inner".tap{p it }; it.', include: Symbol, exclude: String)
     end
 
     def test_if_unless
@@ -642,6 +637,10 @@ module TestReplTypeCompletor
       assert_call('Array::A=1; Array::A&&=1.0; Array::A.', include: Float)
     end
 
+    def test_shareable_constant_value
+      assert_call("#shareable_constant_value:literal\nA=1; A.", include: Integer)
+    end
+
     def test_case_when
       assert_call('case x; when A; 1; when B; 1.0; end.', include: [Integer, Float, NilClass])
       assert_call('case x; when A; 1; when B; 1.0; else; 1r; end.', include: [Integer, Float, Rational], exclude: NilClass)
@@ -695,6 +694,7 @@ module TestReplTypeCompletor
     end
 
     def test_block_args
+      assert_call('[1,2,3].tap{|| 1.', include: Integer)
       assert_call('[1,2,3].tap{|a| a.', include: Array)
       assert_call('[1,2,3].tap{|a,| a.', include: Integer)
       assert_call('[1,2,3].tap{|a,b| a.', include: Integer)
